redhat-redis/icinga-server-port.patch

178 lines
7.1 KiB
Diff

Author: Henrik Triem <henrik.triem@icinga.com>
Date: Tue Jun 01 13:20:51 2021 +0100
Change default server port for icinga-redis
diff --git a/redis.conf b/redis.conf
index ab0a30cbd..d8e51f8ba 100644
--- a/redis.conf
+++ b/redis.conf
@@ -95,7 +95,7 @@
# Accept connections on the specified port, default is 6379 (IANA #815344).
# If port 0 is specified Redis will not listen on a TCP socket.
-port 6379
+port 6380
# TCP listen() backlog.
#
@@ -142,7 +142,7 @@
# default port, use:
#
# port 0
-# tls-port 6379
+# tls-port 6380
# Configure a X.509 certificate and private key to use for authenticating the
# server to connected clients, masters or cluster peers. These files should be
@@ -286,7 +286,7 @@
#
# Note that on modern Linux systems "/run/redis.pid" is more conforming
# and should be used instead.
-pidfile /var/run/redis_6379.pid
+pidfile /var/run/redis_6380.pid
# Specify the server verbosity level.
# This can be one of:
diff --git a/sentinel.conf b/sentinel.conf
index b6ff05f25..2d86376fd 100644
--- a/sentinel.conf
+++ b/sentinel.conf
@@ -18,7 +18,7 @@
# port <sentinel-port>
# The port that this sentinel instance will run on
-port 26379
+port 26380
# By default Redis Sentinel does not run as a daemon. Use 'yes' if you need it.
# Note that Redis will write a pid file in /var/run/redis-sentinel.pid when
@@ -81,7 +81,7 @@
#
# Note: master name should not include special characters or spaces.
# The valid charset is A-z 0-9 and the three characters ".-_".
-sentinel monitor mymaster 127.0.0.1 6379 2
+sentinel monitor mymaster 127.0.0.1 6380 2
# sentinel auth-pass <master-name> <password>
#
diff --git a/src/config.c b/src/config.c
index 4a956d698..bd3100db6 100644
--- a/src/config.c
+++ b/src/config.c
@@ -2475,7 +2475,7 @@
/* Integer configs */
createIntConfig("databases", NULL, IMMUTABLE_CONFIG, 1, INT_MAX, server.dbnum, 16, INTEGER_CONFIG, NULL, NULL),
- createIntConfig("port", NULL, MODIFIABLE_CONFIG, 0, 65535, server.port, 6379, INTEGER_CONFIG, NULL, updatePort), /* TCP port. */
+ createIntConfig("port", NULL, MODIFIABLE_CONFIG, 0, 65535, server.port, 6380, INTEGER_CONFIG, NULL, updatePort), /* TCP port. */
createIntConfig("io-threads", NULL, IMMUTABLE_CONFIG, 1, 128, server.io_threads_num, 1, INTEGER_CONFIG, NULL, NULL), /* Single threaded by default */
createIntConfig("auto-aof-rewrite-percentage", NULL, MODIFIABLE_CONFIG, 0, INT_MAX, server.aof_rewrite_perc, 100, INTEGER_CONFIG, NULL, NULL),
createIntConfig("cluster-replica-validity-factor", "cluster-slave-validity-factor", MODIFIABLE_CONFIG, 0, INT_MAX, server.cluster_slave_validity_factor, 10, INTEGER_CONFIG, NULL, NULL), /* Slave max data age factor. */
diff --git a/src/redis-benchmark.c b/src/redis-benchmark.c
index 9d9c15e00..ff72dc92b 100644
--- a/src/redis-benchmark.c
+++ b/src/redis-benchmark.c
@@ -1555,7 +1555,7 @@
printf(
"Usage: redis-benchmark [-h <host>] [-p <port>] [-c <clients>] [-n <requests>] [-k <boolean>]\n\n"
" -h <hostname> Server hostname (default 127.0.0.1)\n"
-" -p <port> Server port (default 6379)\n"
+" -p <port> Server port (default 6380)\n"
" -s <socket> Server socket (overrides host and port)\n"
" -a <password> Password for Redis Auth\n"
" --user <username> Used to send ACL style 'AUTH username pass'. Needs -a.\n"
@@ -1605,13 +1605,13 @@
" --help Output this help and exit.\n"
" --version Output version and exit.\n\n"
"Examples:\n\n"
-" Run the benchmark with the default configuration against 127.0.0.1:6379:\n"
+" Run the benchmark with the default configuration against 127.0.0.1:6380:\n"
" $ redis-benchmark\n\n"
" Use 20 parallel clients, for a total of 100k requests, against 192.168.1.1:\n"
-" $ redis-benchmark -h 192.168.1.1 -p 6379 -n 100000 -c 20\n\n"
-" Fill 127.0.0.1:6379 with about 1 million keys only using the SET test:\n"
+" $ redis-benchmark -h 192.168.1.1 -p 6380 -n 100000 -c 20\n\n"
+" Fill 127.0.0.1:6380 with about 1 million keys only using the SET test:\n"
" $ redis-benchmark -t set -n 1000000 -r 100000000\n\n"
-" Benchmark 127.0.0.1:6379 for a few commands producing CSV output:\n"
+" Benchmark 127.0.0.1:6380 for a few commands producing CSV output:\n"
" $ redis-benchmark -t ping,set,get -n 100000 --csv\n\n"
" Benchmark a specific command line:\n"
" $ redis-benchmark -r 10000 -n 10000 eval 'return redis.call(\"ping\")' 0\n\n"
@@ -1707,7 +1707,7 @@
config.idlemode = 0;
config.clients = listCreate();
config.hostip = "127.0.0.1";
- config.hostport = 6379;
+ config.hostport = 6380;
config.hostsocket = NULL;
config.tests = NULL;
config.dbnum = 0;
diff --git a/src/redis-cli.c b/src/redis-cli.c
index 45a1228e6..3259b0d37 100644
--- a/src/redis-cli.c
+++ b/src/redis-cli.c
@@ -1828,7 +1828,7 @@
"\n"
"Usage: redis-cli [OPTIONS] [cmd [arg [arg ...]]]\n"
" -h <hostname> Server hostname (default: 127.0.0.1).\n"
-" -p <port> Server port (default: 6379).\n"
+" -p <port> Server port (default: 6380).\n"
" -s <socket> Server socket (overrides hostname and port).\n"
" -a <password> Password to use when connecting to the server.\n"
" You can also use the " REDIS_CLI_AUTH_ENV " environment\n"
@@ -8200,7 +8200,7 @@
memset(&config.sslconfig, 0, sizeof(config.sslconfig));
config.hostip = sdsnew("127.0.0.1");
- config.hostport = 6379;
+ config.hostport = 6380;
config.hostsocket = NULL;
config.repeat = 1;
config.interval = 0;
diff --git a/src/sentinel.c b/src/sentinel.c
index 1bd82453f..d85ee6049 100644
--- a/src/sentinel.c
+++ b/src/sentinel.c
@@ -49,7 +49,7 @@
extern SSL_CTX *redis_tls_client_ctx;
#endif
-#define REDIS_SENTINEL_PORT 26379
+#define REDIS_SENTINEL_PORT 26380
/* ======================== Sentinel global state =========================== */
diff --git a/src/server.c b/src/server.c
index 831349a76..34b9eea3f 100644
--- a/src/server.c
+++ b/src/server.c
@@ -1479,7 +1479,7 @@
NULL /* allow to expand */
};
/* Cluster nodes hash table, mapping nodes addresses 1.2.3.4:6379 to
* clusterNode structures. */
dictType clusterNodesDictType = {
dictSdsHash, /* hash function */
@@ -2687,7 +2687,7 @@
/* Replication related */
server.masterauth = NULL;
server.masterhost = NULL;
- server.masterport = 6379;
+ server.masterport = 6380;
server.master = NULL;
server.cached_master = NULL;
server.master_initial_offset = -1;
@@ -5590,7 +5590,7 @@
fprintf(stderr," ./redis-server --test-memory <megabytes>\n\n");
fprintf(stderr,"Examples:\n");
fprintf(stderr," ./redis-server (run the server with default conf)\n");
- fprintf(stderr," ./redis-server /etc/redis/6379.conf\n");
+ fprintf(stderr," ./redis-server /etc/redis/6380.conf\n");
fprintf(stderr," ./redis-server --port 7777\n");
fprintf(stderr," ./redis-server --port 7777 --replicaof 127.0.0.1 8888\n");
fprintf(stderr," ./redis-server /etc/myredis.conf --loglevel verbose -\n");
@@ -1479,7 +1479,7 @@
NULL /* allow to expand */
};
-/* Cluster nodes hash table, mapping nodes addresses 1.2.3.4:6379 to
+/* Cluster nodes hash table, mapping nodes addresses 1.2.3.4:6380 to
* clusterNode structures. */
dictType clusterNodesDictType = {